stereo.tools.Clustering
=======================

.. currentmodule:: stereo.tools

.. autoclass:: Clustering

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Clustering.__init__
      ~Clustering.add_result
      ~Clustering.check_param
      ~Clustering.fit
      ~Clustering.get_dim_reduce_x
      ~Clustering.get_params
      ~Clustering.run_knn_leiden
      ~Clustering.run_louvain
      ~Clustering.run_neighbors
      ~Clustering.run_normalize
      ~Clustering.sparse2array
   
   

   
   
   